calc_mean_dist: Calculating the mean distances of each plot in the lineup.
Description
Calculates the mean distance, using the provided metric, between the true plot
and all the null plots in a lineup, and all the null plots in the lineup from
each other.
Usage
calc_mean_dist(lineup.dat, var, met, pos, dist.arg = NULL, m = 20)
Value
the mean distances of each plot in the lineup
Arguments
lineup.dat
lineup data of the lineup
var
a vector of names of the variables to be used to calculate the mean distances
met
distance metric needed to calculate the distance as a character
pos
position of the true plot in the lineup
dist.arg
a list or vector of inputs for the distance metric met; NULL by default